# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: anonstore.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import common_pb2 as common__pb2
import pubkey_pb2 as pubkey__pb2
import ct_pb2 as ct__pb2
import certificate_pb2 as certificate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='anonstore.proto',
  package='zsearch',
  syntax='proto3',
  serialized_pb=_b('\n\x0f\x61nonstore.proto\x12\x07zsearch\x1a\x0c\x63ommon.proto\x1a\x0cpubkey.proto\x1a\x08\x63t.proto\x1a\x11\x63\x65rtificate.proto\"\x88\x03\n\x0f\x41nonymousRecord\x12\x10\n\x08sha256fp\x18\x01 \x01(\x0c\x12\x11\n\ttimestamp\x18\x02 \x01(\x10\x12\x0f\n\x07scan_id\x18\x03 \x01(\r\x12\x14\n\x08\x65xported\x18\x04 \x01(\x08\x42\x02\x18\x01\x12\'\n\x08userdata\x18\x05 \x01(\x0b\x32\x15.zsearch.UserdataAtom\x12\x0e\n\x04\x64\x61ta\x18\x06 \x01(\tH\x00\x12\x12\n\x08raw_data\x18\x07 \x01(\x0cH\x00\x12+\n\x0b\x63\x65rtificate\x18\x08 \x01(\x0b\x32\x14.zsearch.CertificateH\x00\x12(\n\x03key\x18\t \x01(\x0b\x32\x19.zsearch.CryptographicKeyH\x00\x12\x1d\n\x02\x61s\x18\n \x01(\x0b\x32\x0f.zsearch.ASAtomH\x00\x12$\n\x08metadata\x18\x0e \x03(\x0b\x32\x12.zsearch.Metadatum\x12\x0c\n\x04tags\x18\x0f \x03(\t\x12\x12\n\nupdated_at\x18\x10 \x01(\x07\x12\x10\n\x08\x61\x64\x64\x65\x64_at\x18\x11 \x01(\x07\x42\x0c\n\noneof_data\"\xbe\x02\n\x0e\x41nonymousDelta\x12\x35\n\ndelta_type\x18\x01 \x01(\x0e\x32!.zsearch.AnonymousDelta.DeltaType\x12\x37\n\x0b\x64\x65lta_scope\x18\x02 \x01(\x0e\x32\".zsearch.AnonymousDelta.DeltaScope\x12(\n\x06record\x18\x03 \x01(\x0b\x32\x18.zsearch.AnonymousRecord\":\n\tDeltaType\x12\x0f\n\x0b\x44T_RESERVED\x10\x00\x12\r\n\tDT_UPDATE\x10\x01\x12\r\n\tDT_DELETE\x10\x02\"V\n\nDeltaScope\x12\x12\n\x0eSCOPE_RESERVED\x10\x00\x12\x13\n\x0fSCOPE_NO_CHANGE\x10\x01\x12\r\n\tSCOPE_NEW\x10\x02\x12\x10\n\x0cSCOPE_UPDATE\x10\x03\"\x8e\x02\n\x13\x45xternalCertificate\x12*\n\x06source\x18\x01 \x01(\x0e\x32\x1a.zsearch.CertificateSource\x12\x32\n\x10\x61nonymous_record\x18\x02 \x01(\x0b\x32\x18.zsearch.AnonymousRecord\x12$\n\tct_server\x18\x03 \x01(\x0e\x32\x11.zsearch.CTServer\x12*\n\tct_status\x18\x04 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x34\n\nnss_status\x18\x05 \x01(\x0b\x32 .zsearch.MozillaSalesForceStatus\x12\x0f\n\x07tbsHash\x18\x06 \x01(\x0c\x62\x06proto3')
  ,
  dependencies=[common__pb2.DESCRIPTOR,pubkey__pb2.DESCRIPTOR,ct__pb2.DESCRIPTOR,certificate__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_ANONYMOUSDELTA_DELTATYPE = _descriptor.EnumDescriptor(
  name='DeltaType',
  full_name='zsearch.AnonymousDelta.DeltaType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DT_RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DT_UPDATE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DT_DELETE', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=653,
  serialized_end=711,
)
_sym_db.RegisterEnumDescriptor(_ANONYMOUSDELTA_DELTATYPE)

_ANONYMOUSDELTA_DELTASCOPE = _descriptor.EnumDescriptor(
  name='DeltaScope',
  full_name='zsearch.AnonymousDelta.DeltaScope',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SCOPE_RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCOPE_NO_CHANGE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCOPE_NEW', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCOPE_UPDATE', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=713,
  serialized_end=799,
)
_sym_db.RegisterEnumDescriptor(_ANONYMOUSDELTA_DELTASCOPE)


_ANONYMOUSRECORD = _descriptor.Descriptor(
  name='AnonymousRecord',
  full_name='zsearch.AnonymousRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sha256fp', full_name='zsearch.AnonymousRecord.sha256fp', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='zsearch.AnonymousRecord.timestamp', index=1,
      number=2, type=16, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scan_id', full_name='zsearch.AnonymousRecord.scan_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exported', full_name='zsearch.AnonymousRecord.exported', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='userdata', full_name='zsearch.AnonymousRecord.userdata', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='zsearch.AnonymousRecord.data', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='raw_data', full_name='zsearch.AnonymousRecord.raw_data', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='certificate', full_name='zsearch.AnonymousRecord.certificate', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='key', full_name='zsearch.AnonymousRecord.key', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='as', full_name='zsearch.AnonymousRecord.as', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='zsearch.AnonymousRecord.metadata', index=10,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tags', full_name='zsearch.AnonymousRecord.tags', index=11,
      number=15, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='zsearch.AnonymousRecord.updated_at', index=12,
      number=16, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='added_at', full_name='zsearch.AnonymousRecord.added_at', index=13,
      number=17, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='oneof_data', full_name='zsearch.AnonymousRecord.oneof_data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=86,
  serialized_end=478,
)


_ANONYMOUSDELTA = _descriptor.Descriptor(
  name='AnonymousDelta',
  full_name='zsearch.AnonymousDelta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='delta_type', full_name='zsearch.AnonymousDelta.delta_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='delta_scope', full_name='zsearch.AnonymousDelta.delta_scope', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='record', full_name='zsearch.AnonymousDelta.record', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ANONYMOUSDELTA_DELTATYPE,
    _ANONYMOUSDELTA_DELTASCOPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=481,
  serialized_end=799,
)


_EXTERNALCERTIFICATE = _descriptor.Descriptor(
  name='ExternalCertificate',
  full_name='zsearch.ExternalCertificate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='zsearch.ExternalCertificate.source', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='anonymous_record', full_name='zsearch.ExternalCertificate.anonymous_record', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ct_server', full_name='zsearch.ExternalCertificate.ct_server', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ct_status', full_name='zsearch.ExternalCertificate.ct_status', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nss_status', full_name='zsearch.ExternalCertificate.nss_status', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tbsHash', full_name='zsearch.ExternalCertificate.tbsHash', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=802,
  serialized_end=1072,
)

_ANONYMOUSRECORD.fields_by_name['userdata'].message_type = common__pb2._USERDATAATOM
_ANONYMOUSRECORD.fields_by_name['certificate'].message_type = certificate__pb2._CERTIFICATE
_ANONYMOUSRECORD.fields_by_name['key'].message_type = pubkey__pb2._CRYPTOGRAPHICKEY
_ANONYMOUSRECORD.fields_by_name['as'].message_type = common__pb2._ASATOM
_ANONYMOUSRECORD.fields_by_name['metadata'].message_type = common__pb2._METADATUM
_ANONYMOUSRECORD.oneofs_by_name['oneof_data'].fields.append(
  _ANONYMOUSRECORD.fields_by_name['data'])
_ANONYMOUSRECORD.fields_by_name['data'].containing_oneof = _ANONYMOUSRECORD.oneofs_by_name['oneof_data']
_ANONYMOUSRECORD.oneofs_by_name['oneof_data'].fields.append(
  _ANONYMOUSRECORD.fields_by_name['raw_data'])
_ANONYMOUSRECORD.fields_by_name['raw_data'].containing_oneof = _ANONYMOUSRECORD.oneofs_by_name['oneof_data']
_ANONYMOUSRECORD.oneofs_by_name['oneof_data'].fields.append(
  _ANONYMOUSRECORD.fields_by_name['certificate'])
_ANONYMOUSRECORD.fields_by_name['certificate'].containing_oneof = _ANONYMOUSRECORD.oneofs_by_name['oneof_data']
_ANONYMOUSRECORD.oneofs_by_name['oneof_data'].fields.append(
  _ANONYMOUSRECORD.fields_by_name['key'])
_ANONYMOUSRECORD.fields_by_name['key'].containing_oneof = _ANONYMOUSRECORD.oneofs_by_name['oneof_data']
_ANONYMOUSRECORD.oneofs_by_name['oneof_data'].fields.append(
  _ANONYMOUSRECORD.fields_by_name['as'])
_ANONYMOUSRECORD.fields_by_name['as'].containing_oneof = _ANONYMOUSRECORD.oneofs_by_name['oneof_data']
_ANONYMOUSDELTA.fields_by_name['delta_type'].enum_type = _ANONYMOUSDELTA_DELTATYPE
_ANONYMOUSDELTA.fields_by_name['delta_scope'].enum_type = _ANONYMOUSDELTA_DELTASCOPE
_ANONYMOUSDELTA.fields_by_name['record'].message_type = _ANONYMOUSRECORD
_ANONYMOUSDELTA_DELTATYPE.containing_type = _ANONYMOUSDELTA
_ANONYMOUSDELTA_DELTASCOPE.containing_type = _ANONYMOUSDELTA
_EXTERNALCERTIFICATE.fields_by_name['source'].enum_type = certificate__pb2._CERTIFICATESOURCE
_EXTERNALCERTIFICATE.fields_by_name['anonymous_record'].message_type = _ANONYMOUSRECORD
_EXTERNALCERTIFICATE.fields_by_name['ct_server'].enum_type = ct__pb2._CTSERVER
_EXTERNALCERTIFICATE.fields_by_name['ct_status'].message_type = ct__pb2._CTSERVERSTATUS
_EXTERNALCERTIFICATE.fields_by_name['nss_status'].message_type = certificate__pb2._MOZILLASALESFORCESTATUS
DESCRIPTOR.message_types_by_name['AnonymousRecord'] = _ANONYMOUSRECORD
DESCRIPTOR.message_types_by_name['AnonymousDelta'] = _ANONYMOUSDELTA
DESCRIPTOR.message_types_by_name['ExternalCertificate'] = _EXTERNALCERTIFICATE

AnonymousRecord = _reflection.GeneratedProtocolMessageType('AnonymousRecord', (_message.Message,), dict(
  DESCRIPTOR = _ANONYMOUSRECORD,
  __module__ = 'anonstore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.AnonymousRecord)
  ))
_sym_db.RegisterMessage(AnonymousRecord)

AnonymousDelta = _reflection.GeneratedProtocolMessageType('AnonymousDelta', (_message.Message,), dict(
  DESCRIPTOR = _ANONYMOUSDELTA,
  __module__ = 'anonstore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.AnonymousDelta)
  ))
_sym_db.RegisterMessage(AnonymousDelta)

ExternalCertificate = _reflection.GeneratedProtocolMessageType('ExternalCertificate', (_message.Message,), dict(
  DESCRIPTOR = _EXTERNALCERTIFICATE,
  __module__ = 'anonstore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.ExternalCertificate)
  ))
_sym_db.RegisterMessage(ExternalCertificate)


_ANONYMOUSRECORD.fields_by_name['exported'].has_options = True
_ANONYMOUSRECORD.fields_by_name['exported']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
# @@protoc_insertion_point(module_scope)
