# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ct.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ct.proto',
  package='zsearch',
  syntax='proto3',
  serialized_pb=_b('\n\x08\x63t.proto\x12\x07zsearch\"\xb2\x01\n\x0e\x43TServerStatus\x12\r\n\x05index\x18\x01 \x01(\x03\x12\x14\n\x0c\x63t_timestamp\x18\x02 \x01(\x03\x12\x16\n\x0epull_timestamp\x18\x03 \x01(\x03\x12\x16\n\x0epush_timestamp\x18\x04 \x01(\x03\x12*\n\x0bpush_status\x18\x05 \x01(\x0e\x32\x15.zsearch.CTPushStatus\x12\x0b\n\x03sct\x18\x06 \x01(\x0c\x12\x12\n\npush_error\x18\x07 \x01(\t\"\x87\r\n\x08\x43TStatus\x12+\n\ncensys_dev\x18\x01 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\'\n\x06\x63\x65nsys\x18\x02 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12/\n\x0egoogle_aviator\x18\n \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12-\n\x0cgoogle_pilot\x18\x0b \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x31\n\x10google_rocketeer\x18\x0c \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x32\n\x11google_submariner\x18\r \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x30\n\x0fgoogle_testtube\x18\x0e \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12.\n\rgoogle_icarus\x18\x0f \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x30\n\x0fgoogle_skydiver\x18\x10 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x30\n\x0fgoogle_daedalus\x18\x11 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12-\n\x0c\x64igicert_ct1\x18\x14 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12-\n\x0c\x64igicert_ct2\x18( \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12.\n\rizenpe_com_ct\x18\x15 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12.\n\rizenpe_eus_ct\x18\x16 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12/\n\x0esymantec_ws_ct\x18\x17 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x31\n\x10symantec_ws_vega\x18\x18 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x33\n\x12symantec_ws_sirius\x18% \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x32\n\x11symantec_ws_deneb\x18  \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12,\n\x0b\x63omodo_dodo\x18\" \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12/\n\x0e\x63omodo_mammoth\x18# \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12-\n\x0c\x63omodo_sabre\x18) \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12-\n\x0cwosign_ctlog\x18\x19 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12*\n\twosign_ct\x18\x1a \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12(\n\x07gdca_ct\x18\x1c \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12+\n\ngdca_ctlog\x18$ \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x31\n\x10venafi_api_ctlog\x18\x1f \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x36\n\x15venafi_api_ctlog_gen2\x18\' \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x33\n\x12nordu_ct_plausible\x18! \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12/\n\x0e\x63nnic_ctserver\x18\x1b \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12,\n\x0bstartssl_ct\x18\x1d \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12+\n\ncertly_log\x18\x1e \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12)\n\x08sheca_ct\x18* \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12>\n\x1d\x63\x65rtificatetransparency_cn_ct\x18& \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x36\n\x15letsencrypt_ct_clicky\x18+ \x01(\x0b\x32\x17.zsearch.CTServerStatus\"c\n\x03SCT\x12\x10\n\x08sha256fp\x18\x01 \x01(\x0c\x12!\n\x06server\x18\x02 \x01(\x0e\x32\x11.zsearch.CTServer\x12\'\n\x06status\x18\x03 \x01(\x0b\x32\x17.zsearch.CTServerStatus*\xeb\x01\n\x0c\x43TPushStatus\x12\x1b\n\x17\x43T_PUSH_STATUS_RESERVED\x10\x00\x12\x1a\n\x16\x43T_PUSH_STATUS_UNKNOWN\x10\x01\x12\x1a\n\x16\x43T_PUSH_STATUS_SUCCESS\x10\x02\x12 \n\x1c\x43T_PUSH_STATUS_UNKNOWN_ERROR\x10\x03\x12\x1f\n\x1b\x43T_PUSH_STATUS_INVALID_ROOT\x10\x04\x12!\n\x1d\x43T_PUSH_STATUS_ALREADY_EXISTS\x10\x05\x12 \n\x1c\x43T_PUSH_STATUS_WILL_NOT_PUSH\x10\x06*\xac\x08\n\x08\x43TServer\x12\x16\n\x12\x43T_SERVER_RESERVED\x10\x00\x12\x1f\n\x1b\x43T_SERVER_CENSYS_PRODUCTION\x10\x01\x12 \n\x1c\x43T_SERVER_CENSYS_DEVELOPMENT\x10\x02\x12\x1a\n\x16\x43T_SERVER_GOOGLE_PILOT\x10\x0b\x12\x1e\n\x1a\x43T_SERVER_GOOGLE_ROCKETEER\x10\x0c\x12\x1f\n\x1b\x43T_SERVER_GOOGLE_SUBMARINER\x10\r\x12\x1d\n\x19\x43T_SERVER_GOOGLE_TESTTUBE\x10\x0e\x12\x1b\n\x17\x43T_SERVER_GOOGLE_ICARUS\x10\x0f\x12\x1d\n\x19\x43T_SERVER_GOOGLE_SKYDIVER\x10\x10\x12\x1d\n\x19\x43T_SERVER_GOOGLE_DAEDALUS\x10\x11\x12\x1c\n\x18\x43T_SERVER_GOOGLE_AVIATOR\x10\n\x12\x1c\n\x18\x43T_SERVER_SYMANTEC_WS_CT\x10\x17\x12\x1e\n\x1a\x43T_SERVER_SYMANTEC_WS_VEGA\x10\x18\x12\x1f\n\x1b\x43T_SERVER_SYMANTEC_WS_DENEB\x10 \x12 \n\x1c\x43T_SERVER_SYMANTEC_WS_SIRIUS\x10%\x12\x19\n\x15\x43T_SERVER_COMODO_DODO\x10#\x12\x1c\n\x18\x43T_SERVER_COMODO_MAMMOTH\x10$\x12\x1a\n\x16\x43T_SERVER_COMODO_SABRE\x10)\x12\x1a\n\x16\x43T_SERVER_WOSIGN_CTLOG\x10\x19\x12\x17\n\x13\x43T_SERVER_WOSIGN_CT\x10\x1a\x12\x1e\n\x1a\x43T_SERVER_VENAFI_API_CTLOG\x10\x1f\x12#\n\x1f\x43T_SERVER_VENAFI_API_CTLOG_GEN2\x10\'\x12\x15\n\x11\x43T_SERVER_GDCA_CT\x10\x1c\x12\x18\n\x14\x43T_SERVER_GDCA_CTLOG\x10\"\x12\x1b\n\x17\x43T_SERVER_IZENPE_COM_CT\x10\x15\x12\x1b\n\x17\x43T_SERVER_IZENPE_EUS_CT\x10\x16\x12\x1a\n\x16\x43T_SERVER_DIGICERT_CT1\x10\x14\x12\x1a\n\x16\x43T_SERVER_DIGICERT_CT2\x10(\x12\x1c\n\x18\x43T_SERVER_CNNIC_CTSERVER\x10\x1b\x12\x19\n\x15\x43T_SERVER_STARTSSL_CT\x10\x1d\x12\x18\n\x14\x43T_SERVER_CERTLY_LOG\x10\x1e\x12 \n\x1c\x43T_SERVER_NORDU_CT_PLAUSIBLE\x10!\x12+\n\'CT_SERVER_CERTIFICATETRANSPARENCY_CN_CT\x10&\x12\x16\n\x12\x43T_SERVER_SHECA_CT\x10*\x12#\n\x1f\x43T_SERVER_LETSENCRYPT_CT_CLICKY\x10,b\x06proto3')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_CTPUSHSTATUS = _descriptor.EnumDescriptor(
  name='CTPushStatus',
  full_name='zsearch.CTPushStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CT_PUSH_STATUS_RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_PUSH_STATUS_UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_PUSH_STATUS_SUCCESS', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_PUSH_STATUS_UNKNOWN_ERROR', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_PUSH_STATUS_INVALID_ROOT', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_PUSH_STATUS_ALREADY_EXISTS', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_PUSH_STATUS_WILL_NOT_PUSH', index=6, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1978,
  serialized_end=2213,
)
_sym_db.RegisterEnumDescriptor(_CTPUSHSTATUS)

CTPushStatus = enum_type_wrapper.EnumTypeWrapper(_CTPUSHSTATUS)
_CTSERVER = _descriptor.EnumDescriptor(
  name='CTServer',
  full_name='zsearch.CTServer',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_CENSYS_PRODUCTION', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_CENSYS_DEVELOPMENT', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_GOOGLE_PILOT', index=3, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_GOOGLE_ROCKETEER', index=4, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_GOOGLE_SUBMARINER', index=5, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_GOOGLE_TESTTUBE', index=6, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_GOOGLE_ICARUS', index=7, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_GOOGLE_SKYDIVER', index=8, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_GOOGLE_DAEDALUS', index=9, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_GOOGLE_AVIATOR', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_SYMANTEC_WS_CT', index=11, number=23,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_SYMANTEC_WS_VEGA', index=12, number=24,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_SYMANTEC_WS_DENEB', index=13, number=32,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_SYMANTEC_WS_SIRIUS', index=14, number=37,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_COMODO_DODO', index=15, number=35,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_COMODO_MAMMOTH', index=16, number=36,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_COMODO_SABRE', index=17, number=41,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_WOSIGN_CTLOG', index=18, number=25,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_WOSIGN_CT', index=19, number=26,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_VENAFI_API_CTLOG', index=20, number=31,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_VENAFI_API_CTLOG_GEN2', index=21, number=39,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_GDCA_CT', index=22, number=28,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_GDCA_CTLOG', index=23, number=34,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_IZENPE_COM_CT', index=24, number=21,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_IZENPE_EUS_CT', index=25, number=22,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_DIGICERT_CT1', index=26, number=20,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_DIGICERT_CT2', index=27, number=40,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_CNNIC_CTSERVER', index=28, number=27,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_STARTSSL_CT', index=29, number=29,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_CERTLY_LOG', index=30, number=30,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_NORDU_CT_PLAUSIBLE', index=31, number=33,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_CERTIFICATETRANSPARENCY_CN_CT', index=32, number=38,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_SHECA_CT', index=33, number=42,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_LETSENCRYPT_CT_CLICKY', index=34, number=44,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2216,
  serialized_end=3284,
)
_sym_db.RegisterEnumDescriptor(_CTSERVER)

CTServer = enum_type_wrapper.EnumTypeWrapper(_CTSERVER)
CT_PUSH_STATUS_RESERVED = 0
CT_PUSH_STATUS_UNKNOWN = 1
CT_PUSH_STATUS_SUCCESS = 2
CT_PUSH_STATUS_UNKNOWN_ERROR = 3
CT_PUSH_STATUS_INVALID_ROOT = 4
CT_PUSH_STATUS_ALREADY_EXISTS = 5
CT_PUSH_STATUS_WILL_NOT_PUSH = 6
CT_SERVER_RESERVED = 0
CT_SERVER_CENSYS_PRODUCTION = 1
CT_SERVER_CENSYS_DEVELOPMENT = 2
CT_SERVER_GOOGLE_PILOT = 11
CT_SERVER_GOOGLE_ROCKETEER = 12
CT_SERVER_GOOGLE_SUBMARINER = 13
CT_SERVER_GOOGLE_TESTTUBE = 14
CT_SERVER_GOOGLE_ICARUS = 15
CT_SERVER_GOOGLE_SKYDIVER = 16
CT_SERVER_GOOGLE_DAEDALUS = 17
CT_SERVER_GOOGLE_AVIATOR = 10
CT_SERVER_SYMANTEC_WS_CT = 23
CT_SERVER_SYMANTEC_WS_VEGA = 24
CT_SERVER_SYMANTEC_WS_DENEB = 32
CT_SERVER_SYMANTEC_WS_SIRIUS = 37
CT_SERVER_COMODO_DODO = 35
CT_SERVER_COMODO_MAMMOTH = 36
CT_SERVER_COMODO_SABRE = 41
CT_SERVER_WOSIGN_CTLOG = 25
CT_SERVER_WOSIGN_CT = 26
CT_SERVER_VENAFI_API_CTLOG = 31
CT_SERVER_VENAFI_API_CTLOG_GEN2 = 39
CT_SERVER_GDCA_CT = 28
CT_SERVER_GDCA_CTLOG = 34
CT_SERVER_IZENPE_COM_CT = 21
CT_SERVER_IZENPE_EUS_CT = 22
CT_SERVER_DIGICERT_CT1 = 20
CT_SERVER_DIGICERT_CT2 = 40
CT_SERVER_CNNIC_CTSERVER = 27
CT_SERVER_STARTSSL_CT = 29
CT_SERVER_CERTLY_LOG = 30
CT_SERVER_NORDU_CT_PLAUSIBLE = 33
CT_SERVER_CERTIFICATETRANSPARENCY_CN_CT = 38
CT_SERVER_SHECA_CT = 42
CT_SERVER_LETSENCRYPT_CT_CLICKY = 44



_CTSERVERSTATUS = _descriptor.Descriptor(
  name='CTServerStatus',
  full_name='zsearch.CTServerStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='zsearch.CTServerStatus.index', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ct_timestamp', full_name='zsearch.CTServerStatus.ct_timestamp', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pull_timestamp', full_name='zsearch.CTServerStatus.pull_timestamp', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='push_timestamp', full_name='zsearch.CTServerStatus.push_timestamp', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='push_status', full_name='zsearch.CTServerStatus.push_status', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sct', full_name='zsearch.CTServerStatus.sct', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='push_error', full_name='zsearch.CTServerStatus.push_error', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22,
  serialized_end=200,
)


_CTSTATUS = _descriptor.Descriptor(
  name='CTStatus',
  full_name='zsearch.CTStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='censys_dev', full_name='zsearch.CTStatus.censys_dev', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='censys', full_name='zsearch.CTStatus.censys', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='google_aviator', full_name='zsearch.CTStatus.google_aviator', index=2,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='google_pilot', full_name='zsearch.CTStatus.google_pilot', index=3,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='google_rocketeer', full_name='zsearch.CTStatus.google_rocketeer', index=4,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='google_submariner', full_name='zsearch.CTStatus.google_submariner', index=5,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='google_testtube', full_name='zsearch.CTStatus.google_testtube', index=6,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='google_icarus', full_name='zsearch.CTStatus.google_icarus', index=7,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='google_skydiver', full_name='zsearch.CTStatus.google_skydiver', index=8,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='google_daedalus', full_name='zsearch.CTStatus.google_daedalus', index=9,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='digicert_ct1', full_name='zsearch.CTStatus.digicert_ct1', index=10,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='digicert_ct2', full_name='zsearch.CTStatus.digicert_ct2', index=11,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='izenpe_com_ct', full_name='zsearch.CTStatus.izenpe_com_ct', index=12,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='izenpe_eus_ct', full_name='zsearch.CTStatus.izenpe_eus_ct', index=13,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symantec_ws_ct', full_name='zsearch.CTStatus.symantec_ws_ct', index=14,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symantec_ws_vega', full_name='zsearch.CTStatus.symantec_ws_vega', index=15,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symantec_ws_sirius', full_name='zsearch.CTStatus.symantec_ws_sirius', index=16,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symantec_ws_deneb', full_name='zsearch.CTStatus.symantec_ws_deneb', index=17,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='comodo_dodo', full_name='zsearch.CTStatus.comodo_dodo', index=18,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='comodo_mammoth', full_name='zsearch.CTStatus.comodo_mammoth', index=19,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='comodo_sabre', full_name='zsearch.CTStatus.comodo_sabre', index=20,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wosign_ctlog', full_name='zsearch.CTStatus.wosign_ctlog', index=21,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wosign_ct', full_name='zsearch.CTStatus.wosign_ct', index=22,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gdca_ct', full_name='zsearch.CTStatus.gdca_ct', index=23,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gdca_ctlog', full_name='zsearch.CTStatus.gdca_ctlog', index=24,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='venafi_api_ctlog', full_name='zsearch.CTStatus.venafi_api_ctlog', index=25,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='venafi_api_ctlog_gen2', full_name='zsearch.CTStatus.venafi_api_ctlog_gen2', index=26,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nordu_ct_plausible', full_name='zsearch.CTStatus.nordu_ct_plausible', index=27,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cnnic_ctserver', full_name='zsearch.CTStatus.cnnic_ctserver', index=28,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='startssl_ct', full_name='zsearch.CTStatus.startssl_ct', index=29,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='certly_log', full_name='zsearch.CTStatus.certly_log', index=30,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sheca_ct', full_name='zsearch.CTStatus.sheca_ct', index=31,
      number=42, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='certificatetransparency_cn_ct', full_name='zsearch.CTStatus.certificatetransparency_cn_ct', index=32,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='letsencrypt_ct_clicky', full_name='zsearch.CTStatus.letsencrypt_ct_clicky', index=33,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=203,
  serialized_end=1874,
)


_SCT = _descriptor.Descriptor(
  name='SCT',
  full_name='zsearch.SCT',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sha256fp', full_name='zsearch.SCT.sha256fp', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server', full_name='zsearch.SCT.server', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='zsearch.SCT.status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1876,
  serialized_end=1975,
)

_CTSERVERSTATUS.fields_by_name['push_status'].enum_type = _CTPUSHSTATUS
_CTSTATUS.fields_by_name['censys_dev'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['censys'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['google_aviator'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['google_pilot'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['google_rocketeer'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['google_submariner'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['google_testtube'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['google_icarus'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['google_skydiver'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['google_daedalus'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['digicert_ct1'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['digicert_ct2'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['izenpe_com_ct'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['izenpe_eus_ct'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['symantec_ws_ct'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['symantec_ws_vega'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['symantec_ws_sirius'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['symantec_ws_deneb'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['comodo_dodo'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['comodo_mammoth'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['comodo_sabre'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['wosign_ctlog'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['wosign_ct'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['gdca_ct'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['gdca_ctlog'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['venafi_api_ctlog'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['venafi_api_ctlog_gen2'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['nordu_ct_plausible'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['cnnic_ctserver'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['startssl_ct'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['certly_log'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['sheca_ct'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['certificatetransparency_cn_ct'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['letsencrypt_ct_clicky'].message_type = _CTSERVERSTATUS
_SCT.fields_by_name['server'].enum_type = _CTSERVER
_SCT.fields_by_name['status'].message_type = _CTSERVERSTATUS
DESCRIPTOR.message_types_by_name['CTServerStatus'] = _CTSERVERSTATUS
DESCRIPTOR.message_types_by_name['CTStatus'] = _CTSTATUS
DESCRIPTOR.message_types_by_name['SCT'] = _SCT
DESCRIPTOR.enum_types_by_name['CTPushStatus'] = _CTPUSHSTATUS
DESCRIPTOR.enum_types_by_name['CTServer'] = _CTSERVER

CTServerStatus = _reflection.GeneratedProtocolMessageType('CTServerStatus', (_message.Message,), dict(
  DESCRIPTOR = _CTSERVERSTATUS,
  __module__ = 'ct_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.CTServerStatus)
  ))
_sym_db.RegisterMessage(CTServerStatus)

CTStatus = _reflection.GeneratedProtocolMessageType('CTStatus', (_message.Message,), dict(
  DESCRIPTOR = _CTSTATUS,
  __module__ = 'ct_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.CTStatus)
  ))
_sym_db.RegisterMessage(CTStatus)

SCT = _reflection.GeneratedProtocolMessageType('SCT', (_message.Message,), dict(
  DESCRIPTOR = _SCT,
  __module__ = 'ct_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.SCT)
  ))
_sym_db.RegisterMessage(SCT)


# @@protoc_insertion_point(module_scope)
