# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: certificate.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import common_pb2 as common__pb2
import zlint_pb2 as zlint__pb2
import ct_pb2 as ct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='certificate.proto',
  package='zsearch',
  syntax='proto3',
  serialized_pb=_b('\n\x11\x63\x65rtificate.proto\x12\x07zsearch\x1a\x0c\x63ommon.proto\x1a\x0bzlint.proto\x1a\x08\x63t.proto\"\xc3\x01\n\x0fRootStoreStatus\x12\r\n\x05valid\x18\x01 \x01(\x08\x12\x11\n\twas_valid\x18\x02 \x01(\x08\x12\x14\n\x0ctrusted_path\x18\x03 \x01(\x08\x12\x18\n\x10was_trusted_path\x18\x04 \x01(\x08\x12\x13\n\x0b\x62lacklisted\x18\x05 \x01(\x08\x12\x13\n\x0bwhitelisted\x18\x06 \x01(\x08\x12&\n\x04type\x18\x07 \x01(\x0e\x32\x18.zsearch.CertificateType\x12\x0c\n\x04path\x18\x08 \x03(\x0c\"\x9c\x02\n\x15\x43\x65rtificateValidation\x12%\n\x03nss\x18\x01 \x01(\x0b\x32\x18.zsearch.RootStoreStatus\x12+\n\tmicrosoft\x18\x02 \x01(\x0b\x32\x18.zsearch.RootStoreStatus\x12\'\n\x05\x61pple\x18\x03 \x01(\x0b\x32\x18.zsearch.RootStoreStatus\x12&\n\x04java\x18\x04 \x01(\x0b\x32\x18.zsearch.RootStoreStatus\x12)\n\x07\x61ndroid\x18\x05 \x01(\x0b\x32\x18.zsearch.RootStoreStatus\x12\x33\n\x11google_ct_primary\x18\n \x01(\x0b\x32\x18.zsearch.RootStoreStatus\"\xba\x02\n\x17MozillaSalesForceStatus\x12\x12\n\ncurrent_in\x18\x01 \x01(\x08\x12\x0e\n\x06was_in\x18\x02 \x01(\x08\x12\x12\n\nowner_name\x18\x03 \x01(\t\x12\x13\n\x0bparent_name\x18\x04 \x01(\t\x12\x18\n\x10\x63\x65rtificate_name\x18\x05 \x01(\t\x12\x1a\n\x12\x63\x65rtificate_policy\x18\x06 \x01(\t\x12(\n certification_practice_statement\x18\x07 \x01(\t\x12\x19\n\x11\x63p_same_as_parent\x18\x08 \x01(\x08\x12\x1c\n\x14\x61udit_same_as_parent\x18\t \x01(\x08\x12\x16\n\x0estandard_audit\x18\n \x01(\t\x12\x10\n\x08\x62r_audit\x18\x0b \x01(\t\x12\x0f\n\x07\x61uditor\x18\x0c \x01(\t\"^\n\x15\x43\x65rtificateRevocation\x12\x0f\n\x07revoked\x18\x01 \x01(\x08\x12\x34\n\x06reason\x18\x02 \x01(\x0e\x32$.zsearch.CertificateRevocationReason\"E\n\x10\x43\x65rtificateAudit\x12\x31\n\x07mozilla\x18\x01 \x01(\x0b\x32 .zsearch.MozillaSalesForceStatus\"\xee\t\n\x0b\x43\x65rtificate\x12\x0e\n\x06sha1fp\x18\x01 \x01(\x0c\x12\x10\n\x08sha256fp\x18\x02 \x01(\x0c\x12\x0b\n\x03raw\x18\x03 \x01(\x0c\x12\x0e\n\x06parsed\x18\x04 \x01(\t\x12\x35\n\x0cparse_status\x18, \x01(\x0e\x32\x1f.zsearch.CertificateParseStatus\x12\x15\n\rparse_version\x18\' \x01(\r\x12\x13\n\x0bparse_error\x18/ \x01(\t\x12\x0f\n\x07parents\x18\x05 \x03(\x0c\x12\x17\n\x0fpresented_chain\x18- \x03(\x0c\x12*\n\x06source\x18\x1c \x01(\x0e\x32\x1a.zsearch.CertificateSource\x12\x14\n\x0cseen_in_scan\x18\x1d \x01(\x08\x12\x16\n\x0epost_processed\x18\x1a \x01(\x08\x12\x1e\n\x16post_process_timestamp\x18% \x01(\r\x12\x32\n\nvalidation\x18# \x01(\x0b\x32\x1e.zsearch.CertificateValidation\x12\x1d\n\x02\x63t\x18\x1e \x01(\x0b\x32\x11.zsearch.CTStatus\x12\x1d\n\x05zlint\x18& \x01(\x0b\x32\x0e.zsearch.ZLint\x12\x32\n\nrevocation\x18+ \x01(\x0b\x32\x1e.zsearch.CertificateRevocation\x12(\n\x05\x61udit\x18. \x01(\x0b\x32\x19.zsearch.CertificateAudit\x12\x12\n\nis_precert\x18  \x01(\x08\x12\x17\n\x0fnot_valid_after\x18) \x01(\r\x12\x18\n\x10not_valid_before\x18* \x01(\r\x12\x0e\n\x06in_nss\x18\x06 \x01(\x08\x12\x18\n\x0cin_microsoft\x18\x07 \x01(\x08\x42\x02\x18\x01\x12\x14\n\x08in_apple\x18\x08 \x01(\x08\x42\x02\x18\x01\x12\x1c\n\x14validation_timestamp\x18\n \x01(\r\x12\x15\n\tvalid_nss\x18\x0b \x01(\x08\x42\x02\x18\x01\x12\x1b\n\x0fvalid_microsoft\x18\x0c \x01(\x08\x42\x02\x18\x01\x12\x17\n\x0bvalid_apple\x18\r \x01(\x08\x42\x02\x18\x01\x12\x15\n\rwas_valid_nss\x18\x0e \x01(\x08\x12\x1f\n\x13was_valid_microsoft\x18\x0f \x01(\x08\x42\x02\x18\x01\x12\x1b\n\x0fwas_valid_apple\x18\x10 \x01(\x08\x42\x02\x18\x01\x12\x16\n\nwas_in_nss\x18\x11 \x01(\x08\x42\x02\x18\x01\x12\x1c\n\x10was_in_microsoft\x18\x12 \x01(\x08\x42\x02\x18\x01\x12\x18\n\x0cwas_in_apple\x18\x13 \x01(\x08\x42\x02\x18\x01\x12\x19\n\x11\x63urrent_valid_nss\x18\x14 \x01(\x08\x12#\n\x17\x63urrent_valid_microsoft\x18\x15 \x01(\x08\x42\x02\x18\x01\x12\x1f\n\x13\x63urrent_valid_apple\x18\x16 \x01(\x08\x42\x02\x18\x01\x12\x16\n\x0e\x63urrent_in_nss\x18\x17 \x01(\x08\x12 \n\x14\x63urrent_in_microsoft\x18\x18 \x01(\x08\x42\x02\x18\x01\x12\x1c\n\x10\x63urrent_in_apple\x18\x19 \x01(\x08\x42\x02\x18\x01\x12\x37\n\tnss_audit\x18\x1f \x01(\x0b\x32 .zsearch.MozillaSalesForceStatusB\x02\x18\x01\x12\x1f\n\x13should_post_process\x18\x1b \x01(\x08\x42\x02\x18\x01\x12\x1f\n\x13\x64o_not_post_process\x18$ \x01(\x08\x42\x02\x18\x01*\xa7\x01\n\x0f\x43\x65rtificateType\x12\x1d\n\x19\x43\x45RTIFICATE_TYPE_RESERVED\x10\x00\x12\x1c\n\x18\x43\x45RTIFICATE_TYPE_UNKNOWN\x10\x01\x12\x19\n\x15\x43\x45RTIFICATE_TYPE_LEAF\x10\x02\x12!\n\x1d\x43\x45RTIFICATE_TYPE_INTERMEDIATE\x10\x03\x12\x19\n\x15\x43\x45RTIFICATE_TYPE_ROOT\x10\x04*\xb7\x02\n\x11\x43\x65rtificateSource\x12\x1f\n\x1b\x43\x45RTIFICATE_SOURCE_RESERVED\x10\x00\x12\x1e\n\x1a\x43\x45RTIFICATE_SOURCE_UNKNOWN\x10\x01\x12\x1b\n\x17\x43\x45RTIFICATE_SOURCE_SCAN\x10\x02\x12\x19\n\x15\x43\x45RTIFICATE_SOURCE_CT\x10\x03\x12)\n%CERTIFICATE_SOURCE_MOZILLA_SALESFORCE\x10\x04\x12\x1f\n\x1b\x43\x45RTIFICATE_SOURCE_RESEARCH\x10\x05\x12\x1d\n\x19\x43\x45RTIFICATE_SOURCE_RAPID7\x10\x06\x12\x1d\n\x19\x43\x45RTIFICATE_SOURCE_HUBBLE\x10\x07\x12\x1f\n\x1b\x43\x45RTIFICATE_SOURCE_CT_CHAIN\x10\x08*\xd7\x01\n\x16\x43\x65rtificateParseStatus\x12%\n!CERTIFICATE_PARSE_STATUS_RESERVED\x10\x00\x12$\n CERTIFICATE_PARSE_STATUS_UNKNOWN\x10\x01\x12$\n CERTIFICATE_PARSE_STATUS_SUCCESS\x10\x02\x12!\n\x1d\x43\x45RTIFICATE_PARSE_STATUS_FAIL\x10\x03\x12\'\n#CERTIFICATE_PARSE_STATUS_NOT_PARSED\x10\x04*\xf4\x04\n\x1b\x43\x65rtificateRevocationReason\x12*\n&CERTIFICATE_REVOCATION_REASON_RESERVED\x10\x00\x12)\n%CERTIFICATE_REVOCATION_REASON_UNKNOWN\x10\x01\x12-\n)CERTIFICATE_REVOCATION_REASON_UNSPECIFIED\x10\x02\x12\x30\n,CERTIFICATE_REVOCATION_REASON_KEY_COMPROMISE\x10\x03\x12/\n+CERTIFICATE_REVOCATION_REASON_CA_COMPROMISE\x10\x04\x12\x35\n1CERTIFICATE_REVOCATION_REASON_AFFILIATION_CHANGED\x10\x05\x12,\n(CERTIFICATE_REVOCATION_REASON_SUPERSEDED\x10\x06\x12\x38\n4CERTIFICATE_REVOCATION_REASON_CESSATION_OF_OPERATION\x10\x07\x12\x32\n.CERTIFICATE_REVOCATION_REASON_CERTIFICATE_HOLD\x10\x08\x12\x31\n-CERTIFICATE_REVOCATION_REASON_REMOVE_FROM_CRL\x10\t\x12\x35\n1CERTIFICATE_REVOCATION_REASON_PRIVILEGE_WITHDRAWN\x10\n\x12/\n+CERTIFICATE_REVOCATION_REASON_AA_COMPROMISE\x10\x0b\x62\x06proto3')
  ,
  dependencies=[common__pb2.DESCRIPTOR,zlint__pb2.DESCRIPTOR,ct__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_CERTIFICATETYPE = _descriptor.EnumDescriptor(
  name='CertificateType',
  full_name='zsearch.CertificateType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_TYPE_RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_TYPE_UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_TYPE_LEAF', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_TYPE_INTERMEDIATE', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_TYPE_ROOT', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2302,
  serialized_end=2469,
)
_sym_db.RegisterEnumDescriptor(_CERTIFICATETYPE)

CertificateType = enum_type_wrapper.EnumTypeWrapper(_CERTIFICATETYPE)
_CERTIFICATESOURCE = _descriptor.EnumDescriptor(
  name='CertificateSource',
  full_name='zsearch.CertificateSource',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_SOURCE_RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_SOURCE_UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_SOURCE_SCAN', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_SOURCE_CT', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_SOURCE_MOZILLA_SALESFORCE', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_SOURCE_RESEARCH', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_SOURCE_RAPID7', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_SOURCE_HUBBLE', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_SOURCE_CT_CHAIN', index=8, number=8,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2472,
  serialized_end=2783,
)
_sym_db.RegisterEnumDescriptor(_CERTIFICATESOURCE)

CertificateSource = enum_type_wrapper.EnumTypeWrapper(_CERTIFICATESOURCE)
_CERTIFICATEPARSESTATUS = _descriptor.EnumDescriptor(
  name='CertificateParseStatus',
  full_name='zsearch.CertificateParseStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_PARSE_STATUS_RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_PARSE_STATUS_UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_PARSE_STATUS_SUCCESS', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_PARSE_STATUS_FAIL', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_PARSE_STATUS_NOT_PARSED', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2786,
  serialized_end=3001,
)
_sym_db.RegisterEnumDescriptor(_CERTIFICATEPARSESTATUS)

CertificateParseStatus = enum_type_wrapper.EnumTypeWrapper(_CERTIFICATEPARSESTATUS)
_CERTIFICATEREVOCATIONREASON = _descriptor.EnumDescriptor(
  name='CertificateRevocationReason',
  full_name='zsearch.CertificateRevocationReason',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_REVOCATION_REASON_RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_REVOCATION_REASON_UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_REVOCATION_REASON_UNSPECIFIED', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_REVOCATION_REASON_KEY_COMPROMISE', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_REVOCATION_REASON_CA_COMPROMISE', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_REVOCATION_REASON_AFFILIATION_CHANGED', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_REVOCATION_REASON_SUPERSEDED', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_REVOCATION_REASON_CESSATION_OF_OPERATION', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_REVOCATION_REASON_CERTIFICATE_HOLD', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_REVOCATION_REASON_REMOVE_FROM_CRL', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_REVOCATION_REASON_PRIVILEGE_WITHDRAWN', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_REVOCATION_REASON_AA_COMPROMISE', index=11, number=11,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3004,
  serialized_end=3632,
)
_sym_db.RegisterEnumDescriptor(_CERTIFICATEREVOCATIONREASON)

CertificateRevocationReason = enum_type_wrapper.EnumTypeWrapper(_CERTIFICATEREVOCATIONREASON)
CERTIFICATE_TYPE_RESERVED = 0
CERTIFICATE_TYPE_UNKNOWN = 1
CERTIFICATE_TYPE_LEAF = 2
CERTIFICATE_TYPE_INTERMEDIATE = 3
CERTIFICATE_TYPE_ROOT = 4
CERTIFICATE_SOURCE_RESERVED = 0
CERTIFICATE_SOURCE_UNKNOWN = 1
CERTIFICATE_SOURCE_SCAN = 2
CERTIFICATE_SOURCE_CT = 3
CERTIFICATE_SOURCE_MOZILLA_SALESFORCE = 4
CERTIFICATE_SOURCE_RESEARCH = 5
CERTIFICATE_SOURCE_RAPID7 = 6
CERTIFICATE_SOURCE_HUBBLE = 7
CERTIFICATE_SOURCE_CT_CHAIN = 8
CERTIFICATE_PARSE_STATUS_RESERVED = 0
CERTIFICATE_PARSE_STATUS_UNKNOWN = 1
CERTIFICATE_PARSE_STATUS_SUCCESS = 2
CERTIFICATE_PARSE_STATUS_FAIL = 3
CERTIFICATE_PARSE_STATUS_NOT_PARSED = 4
CERTIFICATE_REVOCATION_REASON_RESERVED = 0
CERTIFICATE_REVOCATION_REASON_UNKNOWN = 1
CERTIFICATE_REVOCATION_REASON_UNSPECIFIED = 2
CERTIFICATE_REVOCATION_REASON_KEY_COMPROMISE = 3
CERTIFICATE_REVOCATION_REASON_CA_COMPROMISE = 4
CERTIFICATE_REVOCATION_REASON_AFFILIATION_CHANGED = 5
CERTIFICATE_REVOCATION_REASON_SUPERSEDED = 6
CERTIFICATE_REVOCATION_REASON_CESSATION_OF_OPERATION = 7
CERTIFICATE_REVOCATION_REASON_CERTIFICATE_HOLD = 8
CERTIFICATE_REVOCATION_REASON_REMOVE_FROM_CRL = 9
CERTIFICATE_REVOCATION_REASON_PRIVILEGE_WITHDRAWN = 10
CERTIFICATE_REVOCATION_REASON_AA_COMPROMISE = 11



_ROOTSTORESTATUS = _descriptor.Descriptor(
  name='RootStoreStatus',
  full_name='zsearch.RootStoreStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='valid', full_name='zsearch.RootStoreStatus.valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='was_valid', full_name='zsearch.RootStoreStatus.was_valid', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='trusted_path', full_name='zsearch.RootStoreStatus.trusted_path', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='was_trusted_path', full_name='zsearch.RootStoreStatus.was_trusted_path', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blacklisted', full_name='zsearch.RootStoreStatus.blacklisted', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='whitelisted', full_name='zsearch.RootStoreStatus.whitelisted', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='zsearch.RootStoreStatus.type', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='path', full_name='zsearch.RootStoreStatus.path', index=7,
      number=8, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=263,
)


_CERTIFICATEVALIDATION = _descriptor.Descriptor(
  name='CertificateValidation',
  full_name='zsearch.CertificateValidation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nss', full_name='zsearch.CertificateValidation.nss', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='microsoft', full_name='zsearch.CertificateValidation.microsoft', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='apple', full_name='zsearch.CertificateValidation.apple', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='java', full_name='zsearch.CertificateValidation.java', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='android', full_name='zsearch.CertificateValidation.android', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='google_ct_primary', full_name='zsearch.CertificateValidation.google_ct_primary', index=5,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=266,
  serialized_end=550,
)


_MOZILLASALESFORCESTATUS = _descriptor.Descriptor(
  name='MozillaSalesForceStatus',
  full_name='zsearch.MozillaSalesForceStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='current_in', full_name='zsearch.MozillaSalesForceStatus.current_in', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='was_in', full_name='zsearch.MozillaSalesForceStatus.was_in', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner_name', full_name='zsearch.MozillaSalesForceStatus.owner_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parent_name', full_name='zsearch.MozillaSalesForceStatus.parent_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='certificate_name', full_name='zsearch.MozillaSalesForceStatus.certificate_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='certificate_policy', full_name='zsearch.MozillaSalesForceStatus.certificate_policy', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='certification_practice_statement', full_name='zsearch.MozillaSalesForceStatus.certification_practice_statement', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cp_same_as_parent', full_name='zsearch.MozillaSalesForceStatus.cp_same_as_parent', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='audit_same_as_parent', full_name='zsearch.MozillaSalesForceStatus.audit_same_as_parent', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='standard_audit', full_name='zsearch.MozillaSalesForceStatus.standard_audit', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='br_audit', full_name='zsearch.MozillaSalesForceStatus.br_audit', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='auditor', full_name='zsearch.MozillaSalesForceStatus.auditor', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=553,
  serialized_end=867,
)


_CERTIFICATEREVOCATION = _descriptor.Descriptor(
  name='CertificateRevocation',
  full_name='zsearch.CertificateRevocation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='revoked', full_name='zsearch.CertificateRevocation.revoked', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reason', full_name='zsearch.CertificateRevocation.reason', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=869,
  serialized_end=963,
)


_CERTIFICATEAUDIT = _descriptor.Descriptor(
  name='CertificateAudit',
  full_name='zsearch.CertificateAudit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mozilla', full_name='zsearch.CertificateAudit.mozilla', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=965,
  serialized_end=1034,
)


_CERTIFICATE = _descriptor.Descriptor(
  name='Certificate',
  full_name='zsearch.Certificate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sha1fp', full_name='zsearch.Certificate.sha1fp', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sha256fp', full_name='zsearch.Certificate.sha256fp', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='raw', full_name='zsearch.Certificate.raw', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parsed', full_name='zsearch.Certificate.parsed', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parse_status', full_name='zsearch.Certificate.parse_status', index=4,
      number=44, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parse_version', full_name='zsearch.Certificate.parse_version', index=5,
      number=39, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parse_error', full_name='zsearch.Certificate.parse_error', index=6,
      number=47, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parents', full_name='zsearch.Certificate.parents', index=7,
      number=5, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='presented_chain', full_name='zsearch.Certificate.presented_chain', index=8,
      number=45, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='source', full_name='zsearch.Certificate.source', index=9,
      number=28, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seen_in_scan', full_name='zsearch.Certificate.seen_in_scan', index=10,
      number=29, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='post_processed', full_name='zsearch.Certificate.post_processed', index=11,
      number=26, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='post_process_timestamp', full_name='zsearch.Certificate.post_process_timestamp', index=12,
      number=37, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='validation', full_name='zsearch.Certificate.validation', index=13,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ct', full_name='zsearch.Certificate.ct', index=14,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='zlint', full_name='zsearch.Certificate.zlint', index=15,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='revocation', full_name='zsearch.Certificate.revocation', index=16,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='audit', full_name='zsearch.Certificate.audit', index=17,
      number=46, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_precert', full_name='zsearch.Certificate.is_precert', index=18,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='not_valid_after', full_name='zsearch.Certificate.not_valid_after', index=19,
      number=41, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='not_valid_before', full_name='zsearch.Certificate.not_valid_before', index=20,
      number=42, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='in_nss', full_name='zsearch.Certificate.in_nss', index=21,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='in_microsoft', full_name='zsearch.Certificate.in_microsoft', index=22,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='in_apple', full_name='zsearch.Certificate.in_apple', index=23,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='validation_timestamp', full_name='zsearch.Certificate.validation_timestamp', index=24,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='valid_nss', full_name='zsearch.Certificate.valid_nss', index=25,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='valid_microsoft', full_name='zsearch.Certificate.valid_microsoft', index=26,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='valid_apple', full_name='zsearch.Certificate.valid_apple', index=27,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='was_valid_nss', full_name='zsearch.Certificate.was_valid_nss', index=28,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='was_valid_microsoft', full_name='zsearch.Certificate.was_valid_microsoft', index=29,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='was_valid_apple', full_name='zsearch.Certificate.was_valid_apple', index=30,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='was_in_nss', full_name='zsearch.Certificate.was_in_nss', index=31,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='was_in_microsoft', full_name='zsearch.Certificate.was_in_microsoft', index=32,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='was_in_apple', full_name='zsearch.Certificate.was_in_apple', index=33,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='current_valid_nss', full_name='zsearch.Certificate.current_valid_nss', index=34,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='current_valid_microsoft', full_name='zsearch.Certificate.current_valid_microsoft', index=35,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='current_valid_apple', full_name='zsearch.Certificate.current_valid_apple', index=36,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='current_in_nss', full_name='zsearch.Certificate.current_in_nss', index=37,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='current_in_microsoft', full_name='zsearch.Certificate.current_in_microsoft', index=38,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='current_in_apple', full_name='zsearch.Certificate.current_in_apple', index=39,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='nss_audit', full_name='zsearch.Certificate.nss_audit', index=40,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='should_post_process', full_name='zsearch.Certificate.should_post_process', index=41,
      number=27, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='do_not_post_process', full_name='zsearch.Certificate.do_not_post_process', index=42,
      number=36, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1037,
  serialized_end=2299,
)

_ROOTSTORESTATUS.fields_by_name['type'].enum_type = _CERTIFICATETYPE
_CERTIFICATEVALIDATION.fields_by_name['nss'].message_type = _ROOTSTORESTATUS
_CERTIFICATEVALIDATION.fields_by_name['microsoft'].message_type = _ROOTSTORESTATUS
_CERTIFICATEVALIDATION.fields_by_name['apple'].message_type = _ROOTSTORESTATUS
_CERTIFICATEVALIDATION.fields_by_name['java'].message_type = _ROOTSTORESTATUS
_CERTIFICATEVALIDATION.fields_by_name['android'].message_type = _ROOTSTORESTATUS
_CERTIFICATEVALIDATION.fields_by_name['google_ct_primary'].message_type = _ROOTSTORESTATUS
_CERTIFICATEREVOCATION.fields_by_name['reason'].enum_type = _CERTIFICATEREVOCATIONREASON
_CERTIFICATEAUDIT.fields_by_name['mozilla'].message_type = _MOZILLASALESFORCESTATUS
_CERTIFICATE.fields_by_name['parse_status'].enum_type = _CERTIFICATEPARSESTATUS
_CERTIFICATE.fields_by_name['source'].enum_type = _CERTIFICATESOURCE
_CERTIFICATE.fields_by_name['validation'].message_type = _CERTIFICATEVALIDATION
_CERTIFICATE.fields_by_name['ct'].message_type = ct__pb2._CTSTATUS
_CERTIFICATE.fields_by_name['zlint'].message_type = zlint__pb2._ZLINT
_CERTIFICATE.fields_by_name['revocation'].message_type = _CERTIFICATEREVOCATION
_CERTIFICATE.fields_by_name['audit'].message_type = _CERTIFICATEAUDIT
_CERTIFICATE.fields_by_name['nss_audit'].message_type = _MOZILLASALESFORCESTATUS
DESCRIPTOR.message_types_by_name['RootStoreStatus'] = _ROOTSTORESTATUS
DESCRIPTOR.message_types_by_name['CertificateValidation'] = _CERTIFICATEVALIDATION
DESCRIPTOR.message_types_by_name['MozillaSalesForceStatus'] = _MOZILLASALESFORCESTATUS
DESCRIPTOR.message_types_by_name['CertificateRevocation'] = _CERTIFICATEREVOCATION
DESCRIPTOR.message_types_by_name['CertificateAudit'] = _CERTIFICATEAUDIT
DESCRIPTOR.message_types_by_name['Certificate'] = _CERTIFICATE
DESCRIPTOR.enum_types_by_name['CertificateType'] = _CERTIFICATETYPE
DESCRIPTOR.enum_types_by_name['CertificateSource'] = _CERTIFICATESOURCE
DESCRIPTOR.enum_types_by_name['CertificateParseStatus'] = _CERTIFICATEPARSESTATUS
DESCRIPTOR.enum_types_by_name['CertificateRevocationReason'] = _CERTIFICATEREVOCATIONREASON

RootStoreStatus = _reflection.GeneratedProtocolMessageType('RootStoreStatus', (_message.Message,), dict(
  DESCRIPTOR = _ROOTSTORESTATUS,
  __module__ = 'certificate_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.RootStoreStatus)
  ))
_sym_db.RegisterMessage(RootStoreStatus)

CertificateValidation = _reflection.GeneratedProtocolMessageType('CertificateValidation', (_message.Message,), dict(
  DESCRIPTOR = _CERTIFICATEVALIDATION,
  __module__ = 'certificate_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.CertificateValidation)
  ))
_sym_db.RegisterMessage(CertificateValidation)

MozillaSalesForceStatus = _reflection.GeneratedProtocolMessageType('MozillaSalesForceStatus', (_message.Message,), dict(
  DESCRIPTOR = _MOZILLASALESFORCESTATUS,
  __module__ = 'certificate_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.MozillaSalesForceStatus)
  ))
_sym_db.RegisterMessage(MozillaSalesForceStatus)

CertificateRevocation = _reflection.GeneratedProtocolMessageType('CertificateRevocation', (_message.Message,), dict(
  DESCRIPTOR = _CERTIFICATEREVOCATION,
  __module__ = 'certificate_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.CertificateRevocation)
  ))
_sym_db.RegisterMessage(CertificateRevocation)

CertificateAudit = _reflection.GeneratedProtocolMessageType('CertificateAudit', (_message.Message,), dict(
  DESCRIPTOR = _CERTIFICATEAUDIT,
  __module__ = 'certificate_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.CertificateAudit)
  ))
_sym_db.RegisterMessage(CertificateAudit)

Certificate = _reflection.GeneratedProtocolMessageType('Certificate', (_message.Message,), dict(
  DESCRIPTOR = _CERTIFICATE,
  __module__ = 'certificate_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.Certificate)
  ))
_sym_db.RegisterMessage(Certificate)


_CERTIFICATE.fields_by_name['in_microsoft'].has_options = True
_CERTIFICATE.fields_by_name['in_microsoft']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['in_apple'].has_options = True
_CERTIFICATE.fields_by_name['in_apple']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['valid_nss'].has_options = True
_CERTIFICATE.fields_by_name['valid_nss']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['valid_microsoft'].has_options = True
_CERTIFICATE.fields_by_name['valid_microsoft']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['valid_apple'].has_options = True
_CERTIFICATE.fields_by_name['valid_apple']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['was_valid_microsoft'].has_options = True
_CERTIFICATE.fields_by_name['was_valid_microsoft']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['was_valid_apple'].has_options = True
_CERTIFICATE.fields_by_name['was_valid_apple']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['was_in_nss'].has_options = True
_CERTIFICATE.fields_by_name['was_in_nss']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['was_in_microsoft'].has_options = True
_CERTIFICATE.fields_by_name['was_in_microsoft']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['was_in_apple'].has_options = True
_CERTIFICATE.fields_by_name['was_in_apple']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['current_valid_microsoft'].has_options = True
_CERTIFICATE.fields_by_name['current_valid_microsoft']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['current_valid_apple'].has_options = True
_CERTIFICATE.fields_by_name['current_valid_apple']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['current_in_microsoft'].has_options = True
_CERTIFICATE.fields_by_name['current_in_microsoft']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['current_in_apple'].has_options = True
_CERTIFICATE.fields_by_name['current_in_apple']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['nss_audit'].has_options = True
_CERTIFICATE.fields_by_name['nss_audit']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['should_post_process'].has_options = True
_CERTIFICATE.fields_by_name['should_post_process']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['do_not_post_process'].has_options = True
_CERTIFICATE.fields_by_name['do_not_post_process']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
# @@protoc_insertion_point(module_scope)
